Kinto
=====

|coc| |gitter| |readthedocs| |pypi| |ci| |main-coverage|

.. |coc| image:: https://img.shields.io/badge/%E2%9D%A4-code%20of%20conduct-blue.svg
    :target: https://github.com/Kinto/kinto/blob/main/CODE_OF_CONDUCT.md
    :alt: Code of conduct

.. |gitter| image:: https://badges.gitter.im/Kinto/kinto.svg
    :target: https://gitter.im/Kinto/kinto

.. |ci| image:: https://github.com/Kinto/kinto/actions/workflows/test.yml/badge.svg
    :target: https://github.com/Kinto/kinto/actions

.. |readthedocs| image:: https://readthedocs.org/projects/kinto/badge/?version=latest
    :target: https://kinto.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |main-coverage| image::
    https://coveralls.io/repos/Kinto/kinto/badge.svg?branch=main
    :alt: Coverage
    :target: https://coveralls.io/r/Kinto/kinto

.. |pypi| image:: https://img.shields.io/pypi/v/kinto.svg
    :target: https://pypi.python.org/pypi/kinto


Kinto is a minimalist JSON storage service with synchronisation and sharing abilities.

* `Online documentation <https://kinto.readthedocs.io/en/latest/>`_
* `Tutorial <https://kinto.readthedocs.io/en/latest/tutorials/first-steps.html>`_
* `Issue tracker <https://github.com/Kinto/kinto/issues>`_
* `Contributing <https://kinto.readthedocs.io/en/latest/community.html#how-to-contribute>`_
* `Try our daily flushed instance at: https://demo.kinto-storage.org/v1/ <https://demo.kinto-storage.org/v1/>`_
* `Docker Hub <https://hub.docker.com/r/kinto/kinto-server>`_

Requirements
------------

* **Python**: 3.8+
* **Backends**: In-memory (development), PostgreSQL 9.5+ (production)
